@@ -254,7 +254,7 @@ pub async fn next_message(
             //@smells
             buf = buf.trim().to_owned();
 
-            debug!("Received Message: {}", &buf);
+            trace!("Received Message: {}", &buf);
 
             if buf.is_empty() {
                 continue;
